using Godot;
using Godot.NativeInterop;

partial class ExportedProperties
{
#pragma warning disable CS0109 // Disable warning about redundant 'new' keyword
    /// <summary>
    /// Cached StringNames for the properties and fields contained in this class, for fast lookup.
    /// </summary>
    public new class PropertyName : global::Godot.GodotObject.PropertyName {
        /// <summary>
        /// Cached name for the 'NotGenerateComplexLamdaProperty' property.
        /// </summary>
        public new static readonly global::Godot.StringName @NotGenerateComplexLamdaProperty = "NotGenerateComplexLamdaProperty";
        /// <summary>
        /// Cached name for the 'NotGenerateLamdaNoFieldProperty' property.
        /// </summary>
        public new static readonly global::Godot.StringName @NotGenerateLamdaNoFieldProperty = "NotGenerateLamdaNoFieldProperty";
        /// <summary>
        /// Cached name for the 'NotGenerateComplexReturnProperty' property.
        /// </summary>
        public new static readonly global::Godot.StringName @NotGenerateComplexReturnProperty = "NotGenerateComplexReturnProperty";
        /// <summary>
        /// Cached name for the 'NotGenerateReturnsProperty' property.
        /// </summary>
        public new static readonly global::Godot.StringName @NotGenerateReturnsProperty = "NotGenerateReturnsProperty";
        /// <summary>
        /// Cached name for the 'FullPropertyString' property.
        /// </summary>
        public new static readonly global::Godot.StringName @FullPropertyString = "FullPropertyString";
        /// <summary>
        /// Cached name for the 'FullPropertyString_Complex' property.
        /// </summary>
        public new static readonly global::Godot.StringName @FullPropertyString_Complex = "FullPropertyString_Complex";
        /// <summary>
        /// Cached name for the 'LamdaPropertyString' property.
        /// </summary>
        public new static readonly global::Godot.StringName @LamdaPropertyString = "LamdaPropertyString";
        /// <summary>
        /// Cached name for the 'PropertyBoolean' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyBoolean = "PropertyBoolean";
        /// <summary>
        /// Cached name for the 'PropertyChar' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyChar = "PropertyChar";
        /// <summary>
        /// Cached name for the 'PropertySByte' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertySByte = "PropertySByte";
        /// <summary>
        /// Cached name for the 'PropertyInt16' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyInt16 = "PropertyInt16";
        /// <summary>
        /// Cached name for the 'PropertyInt32' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyInt32 = "PropertyInt32";
        /// <summary>
        /// Cached name for the 'PropertyInt64' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyInt64 = "PropertyInt64";
        /// <summary>
        /// Cached name for the 'PropertyByte' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyByte = "PropertyByte";
        /// <summary>
        /// Cached name for the 'PropertyUInt16' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyUInt16 = "PropertyUInt16";
        /// <summary>
        /// Cached name for the 'PropertyUInt32' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyUInt32 = "PropertyUInt32";
        /// <summary>
        /// Cached name for the 'PropertyUInt64' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyUInt64 = "PropertyUInt64";
        /// <summary>
        /// Cached name for the 'PropertySingle' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertySingle = "PropertySingle";
        /// <summary>
        /// Cached name for the 'PropertyDouble' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyDouble = "PropertyDouble";
        /// <summary>
        /// Cached name for the 'PropertyString' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyString = "PropertyString";
        /// <summary>
        /// Cached name for the 'PropertyVector2' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyVector2 = "PropertyVector2";
        /// <summary>
        /// Cached name for the 'PropertyVector2I' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyVector2I = "PropertyVector2I";
        /// <summary>
        /// Cached name for the 'PropertyRect2' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyRect2 = "PropertyRect2";
        /// <summary>
        /// Cached name for the 'PropertyRect2I' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyRect2I = "PropertyRect2I";
        /// <summary>
        /// Cached name for the 'PropertyTransform2D' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyTransform2D = "PropertyTransform2D";
        /// <summary>
        /// Cached name for the 'PropertyVector3' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyVector3 = "PropertyVector3";
        /// <summary>
        /// Cached name for the 'PropertyVector3I' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyVector3I = "PropertyVector3I";
        /// <summary>
        /// Cached name for the 'PropertyBasis' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyBasis = "PropertyBasis";
        /// <summary>
        /// Cached name for the 'PropertyQuaternion' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyQuaternion = "PropertyQuaternion";
        /// <summary>
        /// Cached name for the 'PropertyTransform3D' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyTransform3D = "PropertyTransform3D";
        /// <summary>
        /// Cached name for the 'PropertyVector4' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyVector4 = "PropertyVector4";
        /// <summary>
        /// Cached name for the 'PropertyVector4I' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyVector4I = "PropertyVector4I";
        /// <summary>
        /// Cached name for the 'PropertyProjection' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyProjection = "PropertyProjection";
        /// <summary>
        /// Cached name for the 'PropertyAabb' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyAabb = "PropertyAabb";
        /// <summary>
        /// Cached name for the 'PropertyColor' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyColor = "PropertyColor";
        /// <summary>
        /// Cached name for the 'PropertyPlane' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyPlane = "PropertyPlane";
        /// <summary>
        /// Cached name for the 'PropertyCallable' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyCallable = "PropertyCallable";
        /// <summary>
        /// Cached name for the 'PropertySignal' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertySignal = "PropertySignal";
        /// <summary>
        /// Cached name for the 'PropertyEnum' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyEnum = "PropertyEnum";
        /// <summary>
        /// Cached name for the 'PropertyFlagsEnum' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyFlagsEnum = "PropertyFlagsEnum";
        /// <summary>
        /// Cached name for the 'PropertyByteArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyByteArray = "PropertyByteArray";
        /// <summary>
        /// Cached name for the 'PropertyInt32Array' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyInt32Array = "PropertyInt32Array";
        /// <summary>
        /// Cached name for the 'PropertyInt64Array' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyInt64Array = "PropertyInt64Array";
        /// <summary>
        /// Cached name for the 'PropertySingleArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertySingleArray = "PropertySingleArray";
        /// <summary>
        /// Cached name for the 'PropertyDoubleArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyDoubleArray = "PropertyDoubleArray";
        /// <summary>
        /// Cached name for the 'PropertyStringArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyStringArray = "PropertyStringArray";
        /// <summary>
        /// Cached name for the 'PropertyStringArrayEnum' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyStringArrayEnum = "PropertyStringArrayEnum";
        /// <summary>
        /// Cached name for the 'PropertyVector2Array' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyVector2Array = "PropertyVector2Array";
        /// <summary>
        /// Cached name for the 'PropertyVector3Array' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyVector3Array = "PropertyVector3Array";
        /// <summary>
        /// Cached name for the 'PropertyColorArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyColorArray = "PropertyColorArray";
        /// <summary>
        /// Cached name for the 'PropertyGodotObjectOrDerivedArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyGodotObjectOrDerivedArray = "PropertyGodotObjectOrDerivedArray";
        /// <summary>
        /// Cached name for the 'field_StringNameArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @field_StringNameArray = "field_StringNameArray";
        /// <summary>
        /// Cached name for the 'field_NodePathArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @field_NodePathArray = "field_NodePathArray";
        /// <summary>
        /// Cached name for the 'field_RidArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @field_RidArray = "field_RidArray";
        /// <summary>
        /// Cached name for the 'PropertyVariant' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyVariant = "PropertyVariant";
        /// <summary>
        /// Cached name for the 'PropertyGodotObjectOrDerived' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyGodotObjectOrDerived = "PropertyGodotObjectOrDerived";
        /// <summary>
        /// Cached name for the 'PropertyGodotResourceTexture' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyGodotResourceTexture = "PropertyGodotResourceTexture";
        /// <summary>
        /// Cached name for the 'PropertyStringName' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyStringName = "PropertyStringName";
        /// <summary>
        /// Cached name for the 'PropertyNodePath' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyNodePath = "PropertyNodePath";
        /// <summary>
        /// Cached name for the 'PropertyRid' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyRid = "PropertyRid";
        /// <summary>
        /// Cached name for the 'PropertyGodotDictionary' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyGodotDictionary = "PropertyGodotDictionary";
        /// <summary>
        /// Cached name for the 'PropertyGodotArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyGodotArray = "PropertyGodotArray";
        /// <summary>
        /// Cached name for the 'PropertyGodotGenericDictionary' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyGodotGenericDictionary = "PropertyGodotGenericDictionary";
        /// <summary>
        /// Cached name for the 'PropertyGodotGenericArray' property.
        /// </summary>
        public new static readonly global::Godot.StringName @PropertyGodotGenericArray = "PropertyGodotGenericArray";
        /// <summary>
        /// Cached name for the '_notGeneratePropertyString' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_notGeneratePropertyString = "_notGeneratePropertyString";
        /// <summary>
        /// Cached name for the '_notGeneratePropertyInt' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_notGeneratePropertyInt = "_notGeneratePropertyInt";
        /// <summary>
        /// Cached name for the '_fullPropertyString' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fullPropertyString = "_fullPropertyString";
        /// <summary>
        /// Cached name for the '_fullPropertyStringComplex' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_fullPropertyStringComplex = "_fullPropertyStringComplex";
        /// <summary>
        /// Cached name for the '_lamdaPropertyString' field.
        /// </summary>
        public new static readonly global::Godot.StringName @_lamdaPropertyString = "_lamdaPropertyString";
    }
    /// <inheritdoc/>
    [global::System.ComponentModel.EditorBrowsable(global::System.ComponentModel.EditorBrowsableState.Never)]
    protected override bool SetGodotClassPropertyValue(in godot_string_name name, in godot_variant value)
    {
        if (name == PropertyName.@NotGenerateComplexLamdaProperty) {
            this.@NotGenerateComplexLamdaProperty = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@NotGenerateLamdaNoFieldProperty) {
            this.@NotGenerateLamdaNoFieldProperty = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@NotGenerateComplexReturnProperty) {
            this.@NotGenerateComplexReturnProperty = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@NotGenerateReturnsProperty) {
            this.@NotGenerateReturnsProperty = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@FullPropertyString) {
            this.@FullPropertyString = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@FullPropertyString_Complex) {
            this.@FullPropertyString_Complex = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@LamdaPropertyString) {
            this.@LamdaPropertyString = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@PropertyBoolean) {
            this.@PropertyBoolean = global::Godot.NativeInterop.VariantUtils.ConvertTo<bool>(value);
            return true;
        }
        if (name == PropertyName.@PropertyChar) {
            this.@PropertyChar = global::Godot.NativeInterop.VariantUtils.ConvertTo<char>(value);
            return true;
        }
        if (name == PropertyName.@PropertySByte) {
            this.@PropertySByte = global::Godot.NativeInterop.VariantUtils.ConvertTo<sbyte>(value);
            return true;
        }
        if (name == PropertyName.@PropertyInt16) {
            this.@PropertyInt16 = global::Godot.NativeInterop.VariantUtils.ConvertTo<short>(value);
            return true;
        }
        if (name == PropertyName.@PropertyInt32) {
            this.@PropertyInt32 = global::Godot.NativeInterop.VariantUtils.ConvertTo<int>(value);
            return true;
        }
        if (name == PropertyName.@PropertyInt64) {
            this.@PropertyInt64 = global::Godot.NativeInterop.VariantUtils.ConvertTo<long>(value);
            return true;
        }
        if (name == PropertyName.@PropertyByte) {
            this.@PropertyByte = global::Godot.NativeInterop.VariantUtils.ConvertTo<byte>(value);
            return true;
        }
        if (name == PropertyName.@PropertyUInt16) {
            this.@PropertyUInt16 = global::Godot.NativeInterop.VariantUtils.ConvertTo<ushort>(value);
            return true;
        }
        if (name == PropertyName.@PropertyUInt32) {
            this.@PropertyUInt32 = global::Godot.NativeInterop.VariantUtils.ConvertTo<uint>(value);
            return true;
        }
        if (name == PropertyName.@PropertyUInt64) {
            this.@PropertyUInt64 = global::Godot.NativeInterop.VariantUtils.ConvertTo<ulong>(value);
            return true;
        }
        if (name == PropertyName.@PropertySingle) {
            this.@PropertySingle = global::Godot.NativeInterop.VariantUtils.ConvertTo<float>(value);
            return true;
        }
        if (name == PropertyName.@PropertyDouble) {
            this.@PropertyDouble = global::Godot.NativeInterop.VariantUtils.ConvertTo<double>(value);
            return true;
        }
        if (name == PropertyName.@PropertyString) {
            this.@PropertyString = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@PropertyVector2) {
            this.@PropertyVector2 = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector2>(value);
            return true;
        }
        if (name == PropertyName.@PropertyVector2I) {
            this.@PropertyVector2I = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector2I>(value);
            return true;
        }
        if (name == PropertyName.@PropertyRect2) {
            this.@PropertyRect2 = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Rect2>(value);
            return true;
        }
        if (name == PropertyName.@PropertyRect2I) {
            this.@PropertyRect2I = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Rect2I>(value);
            return true;
        }
        if (name == PropertyName.@PropertyTransform2D) {
            this.@PropertyTransform2D = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Transform2D>(value);
            return true;
        }
        if (name == PropertyName.@PropertyVector3) {
            this.@PropertyVector3 = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector3>(value);
            return true;
        }
        if (name == PropertyName.@PropertyVector3I) {
            this.@PropertyVector3I = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector3I>(value);
            return true;
        }
        if (name == PropertyName.@PropertyBasis) {
            this.@PropertyBasis = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Basis>(value);
            return true;
        }
        if (name == PropertyName.@PropertyQuaternion) {
            this.@PropertyQuaternion = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Quaternion>(value);
            return true;
        }
        if (name == PropertyName.@PropertyTransform3D) {
            this.@PropertyTransform3D = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Transform3D>(value);
            return true;
        }
        if (name == PropertyName.@PropertyVector4) {
            this.@PropertyVector4 = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector4>(value);
            return true;
        }
        if (name == PropertyName.@PropertyVector4I) {
            this.@PropertyVector4I = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector4I>(value);
            return true;
        }
        if (name == PropertyName.@PropertyProjection) {
            this.@PropertyProjection = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Projection>(value);
            return true;
        }
        if (name == PropertyName.@PropertyAabb) {
            this.@PropertyAabb = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Aabb>(value);
            return true;
        }
        if (name == PropertyName.@PropertyColor) {
            this.@PropertyColor = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Color>(value);
            return true;
        }
        if (name == PropertyName.@PropertyPlane) {
            this.@PropertyPlane = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Plane>(value);
            return true;
        }
        if (name == PropertyName.@PropertyCallable) {
            this.@PropertyCallable = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Callable>(value);
            return true;
        }
        if (name == PropertyName.@PropertySignal) {
            this.@PropertySignal = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Signal>(value);
            return true;
        }
        if (name == PropertyName.@PropertyEnum) {
            this.@PropertyEnum = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::ExportedProperties.MyEnum>(value);
            return true;
        }
        if (name == PropertyName.@PropertyFlagsEnum) {
            this.@PropertyFlagsEnum = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::ExportedProperties.MyFlagsEnum>(value);
            return true;
        }
        if (name == PropertyName.@PropertyByteArray) {
            this.@PropertyByteArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<byte[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyInt32Array) {
            this.@PropertyInt32Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<int[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyInt64Array) {
            this.@PropertyInt64Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<long[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertySingleArray) {
            this.@PropertySingleArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<float[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyDoubleArray) {
            this.@PropertyDoubleArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<double[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyStringArray) {
            this.@PropertyStringArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<string[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyStringArrayEnum) {
            this.@PropertyStringArrayEnum = global::Godot.NativeInterop.VariantUtils.ConvertTo<string[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyVector2Array) {
            this.@PropertyVector2Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector2[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyVector3Array) {
            this.@PropertyVector3Array = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Vector3[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyColorArray) {
            this.@PropertyColorArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Color[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyGodotObjectOrDerivedArray) {
            this.@PropertyGodotObjectOrDerivedArray = global::Godot.NativeInterop.VariantUtils.ConvertToSystemArrayOfGodotObject<global::Godot.GodotObject>(value);
            return true;
        }
        if (name == PropertyName.@field_StringNameArray) {
            this.@field_StringNameArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.StringName[]>(value);
            return true;
        }
        if (name == PropertyName.@field_NodePathArray) {
            this.@field_NodePathArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.NodePath[]>(value);
            return true;
        }
        if (name == PropertyName.@field_RidArray) {
            this.@field_RidArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Rid[]>(value);
            return true;
        }
        if (name == PropertyName.@PropertyVariant) {
            this.@PropertyVariant = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Variant>(value);
            return true;
        }
        if (name == PropertyName.@PropertyGodotObjectOrDerived) {
            this.@PropertyGodotObjectOrDerived = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.GodotObject>(value);
            return true;
        }
        if (name == PropertyName.@PropertyGodotResourceTexture) {
            this.@PropertyGodotResourceTexture = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Texture>(value);
            return true;
        }
        if (name == PropertyName.@PropertyStringName) {
            this.@PropertyStringName = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.StringName>(value);
            return true;
        }
        if (name == PropertyName.@PropertyNodePath) {
            this.@PropertyNodePath = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.NodePath>(value);
            return true;
        }
        if (name == PropertyName.@PropertyRid) {
            this.@PropertyRid = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Rid>(value);
            return true;
        }
        if (name == PropertyName.@PropertyGodotDictionary) {
            this.@PropertyGodotDictionary = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Collections.Dictionary>(value);
            return true;
        }
        if (name == PropertyName.@PropertyGodotArray) {
            this.@PropertyGodotArray = global::Godot.NativeInterop.VariantUtils.ConvertTo<global::Godot.Collections.Array>(value);
            return true;
        }
        if (name == PropertyName.@PropertyGodotGenericDictionary) {
            this.@PropertyGodotGenericDictionary = global::Godot.NativeInterop.VariantUtils.ConvertToDictionary<string, bool>(value);
            return true;
        }
        if (name == PropertyName.@PropertyGodotGenericArray) {
            this.@PropertyGodotGenericArray = global::Godot.NativeInterop.VariantUtils.ConvertToArray<int>(value);
            return true;
        }
        if (name == PropertyName.@_notGeneratePropertyString) {
            this.@_notGeneratePropertyString = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@_notGeneratePropertyInt) {
            this.@_notGeneratePropertyInt = global::Godot.NativeInterop.VariantUtils.ConvertTo<int>(value);
            return true;
        }
        if (name == PropertyName.@_fullPropertyString) {
            this.@_fullPropertyString = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@_fullPropertyStringComplex) {
            this.@_fullPropertyStringComplex = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        if (name == PropertyName.@_lamdaPropertyString) {
            this.@_lamdaPropertyString = global::Godot.NativeInterop.VariantUtils.ConvertTo<string>(value);
            return true;
        }
        return base.SetGodotClassPropertyValue(name, value);
    }
    /// <inheritdoc/>
    [global::System.ComponentModel.EditorBrowsable(global::System.ComponentModel.EditorBrowsableState.Never)]
    protected override bool GetGodotClassPropertyValue(in godot_string_name name, out godot_variant value)
    {
        if (name == PropertyName.@NotGenerateComplexLamdaProperty) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@NotGenerateComplexLamdaProperty);
            return true;
        }
        if (name == PropertyName.@NotGenerateLamdaNoFieldProperty) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@NotGenerateLamdaNoFieldProperty);
            return true;
        }
        if (name == PropertyName.@NotGenerateComplexReturnProperty) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@NotGenerateComplexReturnProperty);
            return true;
        }
        if (name == PropertyName.@NotGenerateReturnsProperty) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@NotGenerateReturnsProperty);
            return true;
        }
        if (name == PropertyName.@FullPropertyString) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@FullPropertyString);
            return true;
        }
        if (name == PropertyName.@FullPropertyString_Complex) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@FullPropertyString_Complex);
            return true;
        }
        if (name == PropertyName.@LamdaPropertyString) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@LamdaPropertyString);
            return true;
        }
        if (name == PropertyName.@PropertyBoolean) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<bool>(this.@PropertyBoolean);
            return true;
        }
        if (name == PropertyName.@PropertyChar) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<char>(this.@PropertyChar);
            return true;
        }
        if (name == PropertyName.@PropertySByte) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<sbyte>(this.@PropertySByte);
            return true;
        }
        if (name == PropertyName.@PropertyInt16) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<short>(this.@PropertyInt16);
            return true;
        }
        if (name == PropertyName.@PropertyInt32) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<int>(this.@PropertyInt32);
            return true;
        }
        if (name == PropertyName.@PropertyInt64) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<long>(this.@PropertyInt64);
            return true;
        }
        if (name == PropertyName.@PropertyByte) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<byte>(this.@PropertyByte);
            return true;
        }
        if (name == PropertyName.@PropertyUInt16) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<ushort>(this.@PropertyUInt16);
            return true;
        }
        if (name == PropertyName.@PropertyUInt32) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<uint>(this.@PropertyUInt32);
            return true;
        }
        if (name == PropertyName.@PropertyUInt64) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<ulong>(this.@PropertyUInt64);
            return true;
        }
        if (name == PropertyName.@PropertySingle) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<float>(this.@PropertySingle);
            return true;
        }
        if (name == PropertyName.@PropertyDouble) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<double>(this.@PropertyDouble);
            return true;
        }
        if (name == PropertyName.@PropertyString) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@PropertyString);
            return true;
        }
        if (name == PropertyName.@PropertyVector2) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector2>(this.@PropertyVector2);
            return true;
        }
        if (name == PropertyName.@PropertyVector2I) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector2I>(this.@PropertyVector2I);
            return true;
        }
        if (name == PropertyName.@PropertyRect2) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Rect2>(this.@PropertyRect2);
            return true;
        }
        if (name == PropertyName.@PropertyRect2I) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Rect2I>(this.@PropertyRect2I);
            return true;
        }
        if (name == PropertyName.@PropertyTransform2D) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Transform2D>(this.@PropertyTransform2D);
            return true;
        }
        if (name == PropertyName.@PropertyVector3) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector3>(this.@PropertyVector3);
            return true;
        }
        if (name == PropertyName.@PropertyVector3I) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector3I>(this.@PropertyVector3I);
            return true;
        }
        if (name == PropertyName.@PropertyBasis) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Basis>(this.@PropertyBasis);
            return true;
        }
        if (name == PropertyName.@PropertyQuaternion) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Quaternion>(this.@PropertyQuaternion);
            return true;
        }
        if (name == PropertyName.@PropertyTransform3D) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Transform3D>(this.@PropertyTransform3D);
            return true;
        }
        if (name == PropertyName.@PropertyVector4) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector4>(this.@PropertyVector4);
            return true;
        }
        if (name == PropertyName.@PropertyVector4I) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector4I>(this.@PropertyVector4I);
            return true;
        }
        if (name == PropertyName.@PropertyProjection) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Projection>(this.@PropertyProjection);
            return true;
        }
        if (name == PropertyName.@PropertyAabb) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Aabb>(this.@PropertyAabb);
            return true;
        }
        if (name == PropertyName.@PropertyColor) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Color>(this.@PropertyColor);
            return true;
        }
        if (name == PropertyName.@PropertyPlane) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Plane>(this.@PropertyPlane);
            return true;
        }
        if (name == PropertyName.@PropertyCallable) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Callable>(this.@PropertyCallable);
            return true;
        }
        if (name == PropertyName.@PropertySignal) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Signal>(this.@PropertySignal);
            return true;
        }
        if (name == PropertyName.@PropertyEnum) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::ExportedProperties.MyEnum>(this.@PropertyEnum);
            return true;
        }
        if (name == PropertyName.@PropertyFlagsEnum) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::ExportedProperties.MyFlagsEnum>(this.@PropertyFlagsEnum);
            return true;
        }
        if (name == PropertyName.@PropertyByteArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<byte[]>(this.@PropertyByteArray);
            return true;
        }
        if (name == PropertyName.@PropertyInt32Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<int[]>(this.@PropertyInt32Array);
            return true;
        }
        if (name == PropertyName.@PropertyInt64Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<long[]>(this.@PropertyInt64Array);
            return true;
        }
        if (name == PropertyName.@PropertySingleArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<float[]>(this.@PropertySingleArray);
            return true;
        }
        if (name == PropertyName.@PropertyDoubleArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<double[]>(this.@PropertyDoubleArray);
            return true;
        }
        if (name == PropertyName.@PropertyStringArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string[]>(this.@PropertyStringArray);
            return true;
        }
        if (name == PropertyName.@PropertyStringArrayEnum) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string[]>(this.@PropertyStringArrayEnum);
            return true;
        }
        if (name == PropertyName.@PropertyVector2Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector2[]>(this.@PropertyVector2Array);
            return true;
        }
        if (name == PropertyName.@PropertyVector3Array) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Vector3[]>(this.@PropertyVector3Array);
            return true;
        }
        if (name == PropertyName.@PropertyColorArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Color[]>(this.@PropertyColorArray);
            return true;
        }
        if (name == PropertyName.@PropertyGodotObjectOrDerivedArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFromSystemArrayOfGodotObject(this.@PropertyGodotObjectOrDerivedArray);
            return true;
        }
        if (name == PropertyName.@field_StringNameArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.StringName[]>(this.@field_StringNameArray);
            return true;
        }
        if (name == PropertyName.@field_NodePathArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.NodePath[]>(this.@field_NodePathArray);
            return true;
        }
        if (name == PropertyName.@field_RidArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Rid[]>(this.@field_RidArray);
            return true;
        }
        if (name == PropertyName.@PropertyVariant) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Variant>(this.@PropertyVariant);
            return true;
        }
        if (name == PropertyName.@PropertyGodotObjectOrDerived) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.GodotObject>(this.@PropertyGodotObjectOrDerived);
            return true;
        }
        if (name == PropertyName.@PropertyGodotResourceTexture) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Texture>(this.@PropertyGodotResourceTexture);
            return true;
        }
        if (name == PropertyName.@PropertyStringName) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.StringName>(this.@PropertyStringName);
            return true;
        }
        if (name == PropertyName.@PropertyNodePath) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.NodePath>(this.@PropertyNodePath);
            return true;
        }
        if (name == PropertyName.@PropertyRid) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Rid>(this.@PropertyRid);
            return true;
        }
        if (name == PropertyName.@PropertyGodotDictionary) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Collections.Dictionary>(this.@PropertyGodotDictionary);
            return true;
        }
        if (name == PropertyName.@PropertyGodotArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<global::Godot.Collections.Array>(this.@PropertyGodotArray);
            return true;
        }
        if (name == PropertyName.@PropertyGodotGenericDictionary) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFromDictionary(this.@PropertyGodotGenericDictionary);
            return true;
        }
        if (name == PropertyName.@PropertyGodotGenericArray) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFromArray(this.@PropertyGodotGenericArray);
            return true;
        }
        if (name == PropertyName.@_notGeneratePropertyString) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@_notGeneratePropertyString);
            return true;
        }
        if (name == PropertyName.@_notGeneratePropertyInt) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<int>(this.@_notGeneratePropertyInt);
            return true;
        }
        if (name == PropertyName.@_fullPropertyString) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@_fullPropertyString);
            return true;
        }
        if (name == PropertyName.@_fullPropertyStringComplex) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@_fullPropertyStringComplex);
            return true;
        }
        if (name == PropertyName.@_lamdaPropertyString) {
            value = global::Godot.NativeInterop.VariantUtils.CreateFrom<string>(this.@_lamdaPropertyString);
            return true;
        }
        return base.GetGodotClassPropertyValue(name, out value);
    }
    /// <summary>
    /// Get the property information for all the properties declared in this class.
    /// This method is used by Godot to register the available properties in the editor.
    /// Do not call this method.
    /// </summary>
    [global::System.ComponentModel.EditorBrowsable(global::System.ComponentModel.EditorBrowsableState.Never)]
    internal new static global::System.Collections.Generic.List<global::Godot.Bridge.PropertyInfo> GetGodotPropertyList()
    {
        var properties = new global::System.Collections.Generic.List<global::Godot.Bridge.PropertyInfo>();
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@_notGeneratePropertyString, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4096, exported: false));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@NotGenerateComplexLamdaProperty, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@NotGenerateLamdaNoFieldProperty, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@NotGenerateComplexReturnProperty, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@_notGeneratePropertyInt, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4096, exported: false));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@NotGenerateReturnsProperty, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@_fullPropertyString, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4096, exported: false));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@FullPropertyString, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@_fullPropertyStringComplex, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4096, exported: false));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@FullPropertyString_Complex, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@_lamdaPropertyString, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4096, exported: false));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@LamdaPropertyString, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)1, name: PropertyName.@PropertyBoolean, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyChar, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertySByte, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyInt16, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyInt32, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyInt64, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyByte, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyUInt16, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyUInt32, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyUInt64, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)3, name: PropertyName.@PropertySingle, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)3, name: PropertyName.@PropertyDouble, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)4, name: PropertyName.@PropertyString, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)5, name: PropertyName.@PropertyVector2, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)6, name: PropertyName.@PropertyVector2I, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)7, name: PropertyName.@PropertyRect2, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)8, name: PropertyName.@PropertyRect2I, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)11, name: PropertyName.@PropertyTransform2D, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)9, name: PropertyName.@PropertyVector3, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)10, name: PropertyName.@PropertyVector3I, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)17, name: PropertyName.@PropertyBasis, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)15, name: PropertyName.@PropertyQuaternion, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)18, name: PropertyName.@PropertyTransform3D, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)12, name: PropertyName.@PropertyVector4, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)13, name: PropertyName.@PropertyVector4I, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)19, name: PropertyName.@PropertyProjection, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)16, name: PropertyName.@PropertyAabb, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)20, name: PropertyName.@PropertyColor, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)14, name: PropertyName.@PropertyPlane, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)25, name: PropertyName.@PropertyCallable, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)26, name: PropertyName.@PropertySignal, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyEnum, hint: (global::Godot.PropertyHint)2, hintString: "A,B,C", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)2, name: PropertyName.@PropertyFlagsEnum, hint: (global::Godot.PropertyHint)6, hintString: "A:0,B:1,C:2", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)29, name: PropertyName.@PropertyByteArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)30, name: PropertyName.@PropertyInt32Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)31, name: PropertyName.@PropertyInt64Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)32, name: PropertyName.@PropertySingleArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)33, name: PropertyName.@PropertyDoubleArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)34, name: PropertyName.@PropertyStringArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)34, name: PropertyName.@PropertyStringArrayEnum, hint: (global::Godot.PropertyHint)23, hintString: "4/2:A,B,C", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)35, name: PropertyName.@PropertyVector2Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)36, name: PropertyName.@PropertyVector3Array, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)37, name: PropertyName.@PropertyColorArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@PropertyGodotObjectOrDerivedArray, hint: (global::Godot.PropertyHint)23, hintString: "24/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@field_StringNameArray, hint: (global::Godot.PropertyHint)23, hintString: "21/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@field_NodePathArray, hint: (global::Godot.PropertyHint)23, hintString: "22/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@field_RidArray, hint: (global::Godot.PropertyHint)23, hintString: "23/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)0, name: PropertyName.@PropertyVariant, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)135174, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)24, name: PropertyName.@PropertyGodotObjectOrDerived, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)24, name: PropertyName.@PropertyGodotResourceTexture, hint: (global::Godot.PropertyHint)17, hintString: "Texture", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)21, name: PropertyName.@PropertyStringName, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)22, name: PropertyName.@PropertyNodePath, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)23, name: PropertyName.@PropertyRid, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)27, name: PropertyName.@PropertyGodotDictionary, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@PropertyGodotArray, hint: (global::Godot.PropertyHint)0, hintString: "", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)27, name: PropertyName.@PropertyGodotGenericDictionary, hint: (global::Godot.PropertyHint)23, hintString: "4/0:;1/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        properties.Add(new(type: (global::Godot.Variant.Type)28, name: PropertyName.@PropertyGodotGenericArray, hint: (global::Godot.PropertyHint)23, hintString: "2/0:", usage: (global::Godot.PropertyUsageFlags)4102, exported: true));
        return properties;
    }
#pragma warning restore CS0109
}
